@@ -652,8 +652,6 @@ void xconfigFreeVideoPortList(XConfigVideoPortPtr ptr);
 void xconfigFreeBuffersList (XConfigBuffersPtr ptr);
 void xconfigFreeDRI(XConfigDRIPtr ptr);
 void xconfigFreeExtensions(XConfigExtensionsPtr ptr);
-void xconfigFreeModesLinkList(XConfigModesLinkPtr ptr);
-
 
 
 /*
@@ -736,13 +734,4 @@ void xconfigGeneratePrintPossibleKeyboards(void);
 int xconfigCheckCoreInputDevices(GenerateOptions *gop,
                                  XConfigPtr config, XConfigLayoutPtr layout);
 
-
-/*
- * X config tools
- */
-
-int xconfigMergeConfigs(XConfigPtr dstConfig, XConfigPtr srcConfig);
-
-
-
 #endif /* _xf86Parser_h_ */
